import { useLocalStorage } from './useLocalStorage';
import { useEffect, useRef, useState } from 'react';

const HOME_ROUTE = '/';

const getLastVisitedPage = (availableRoutersList: Array<string>) =>
  availableRoutersList[availableRoutersList.length - 1];
const isNotStartedPageAndNotIncludeInList = (
  availableRoutersList: Array<string>,
  pathname: string,
  startPage: any
) =>
  !availableRoutersList.includes(pathname) &&
  startPage.current.pathname !== pathname;

const isValidSearch = (search = '') => {
  if (!search) {
    return false;
  }

  const email = new URLSearchParams(search).get('email');
  const planCode = new URLSearchParams(search).get('planCode');
  const price = new URLSearchParams(search).get('price');
  const gender = new URLSearchParams(search).get('gender');
  const status = new URLSearchParams(search).get('relationship-status');
  const redirect_to = new URLSearchParams(search).get('redirect_to');

  return email && email.includes('@') && planCode && price && gender && status && redirect_to;
};

export const useAccessPageChecking = (pathname: string, search?: string) => {
  const startPage = useRef({ pathname });
  const [routerAvailable, doRouterAvailable] = useState(false);
  const { pageValue: availableRoutersList, setPageValue: addAvailableRoute } =
    useLocalStorage({
      key: 'available_routes',
      defaultValue: ['/'],
    });

  useEffect(() => {
    if (availableRoutersList?.includes(pathname)) {
      doRouterAvailable(true);
    } else if (pathname === '/heyflow-payment' && isValidSearch(search)) {
      addAvailableRoute([pathname]);
      doRouterAvailable(true);
    } else if (
      pathname === HOME_ROUTE &&
      !availableRoutersList?.includes(pathname)
    ) {
      addAvailableRoute([pathname]);
      doRouterAvailable(true);
    } else {
      window.location.pathname = getLastVisitedPage(availableRoutersList);
    }
  }, []);

  useEffect(() => {
    if (
      isNotStartedPageAndNotIncludeInList(
        availableRoutersList,
        pathname,
        startPage
      )
    ) {
      addAvailableRoute([...availableRoutersList, pathname]);
    }
  }, [pathname]);

  return {
    routerAvailable,
  };
};
